/*************************************************************************\
* Copyright (c) 1995-2010 UChicago Argonne LLC, as Operator of Argonne
*     National Laboratory.
* This software is distributed subject to a Software License Agreement
* found in the file LICENSE that is included with this distribution.
\*************************************************************************/

/*************************************************************************
 * FILE:      rctest.c
 * Author:    Claude Saunders
 * 
 * Purpose:   Application to test out function of runControl library
 *            and runcontrol record support.
 *************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <cadef.h>
#if defined(_WIN32)
#include <windows.h>
#define sleep(sec) Sleep(sec * 1000)
#else
#include <unistd.h>
#endif
#include <signal.h>

#include <libruncontrol.h>

void exitHandler(int sig);

char handle[255];
RUNCONTROL_INFO rcInfo;

int loop;

int main(int argc, char *argv[]) {
  char pv[255];
  int status;

  strcpy(pv,"APS:RunControlFixed0RC");
  if (argc < 2) {
     fprintf(stderr,"usage: %s <description-string>\n\n",argv[0]);
     exit(1);
  }
  
  status = runControlInit(pv, argv[1], 8000.0, handle, &rcInfo, 10.0);
  if (status == RUNCONTROL_DENIED) {
    fprintf(stderr,"Run access denied, record in use.\n");
    exit(1);
  }
  if (status != RUNCONTROL_OK) {
    fprintf(stderr,"ERROR %d initializing run control\n", status);
    exit(1);
  }
  signal(SIGINT, exitHandler);

  fprintf(stderr,"Access permitted, running...\n");

  loop = 1;
  while (loop) {
    status = runControlPing(handle, &rcInfo);
    switch (status) {
    case RUNCONTROL_ABORT:
      fprintf(stderr,"Application aborted\n");
      runControlExit(handle, &rcInfo);
      return(1);
    case RUNCONTROL_TIMEOUT:
      fprintf(stderr,"Application timed out\n");
      return(1);
    case RUNCONTROL_OK:
      sleep(5);
      status = runControlLogMessage(handle, "I'm up", NO_ALARM, &rcInfo);
      if (status != RUNCONTROL_OK) {
	fprintf(stderr,"Unable to log message, exiting\n");
	return(1);
      }
      break;
    case RUNCONTROL_ERROR:
      fprintf(stderr,"Error during ping operation\n");
      return(1);
    default:
      fprintf(stderr,"Unknown error code\n");
      return(1);
    }
  }
  return(0);
}

void exitHandler(int sig) {
  runControlExit(handle, &rcInfo);
  loop = 0;
}
